@@ -1,11 +1,13 @@
 from ._plot import plot
-from ._progress import log_split_progress
+from ._progress import default_metrics_formatter, log_split_progress
 from ._split import split
-from ._to_string import to_string
+from ._to_string import format_expanded_limits, to_string
 from ._weight import fold_weight
 
 __all__ = [
+    "default_metrics_formatter",
     "fold_weight",
+    "format_expanded_limits",
     "log_split_progress",
     "plot",
     "split",
