@@ -1,18 +1,15 @@
 import logging
 from collections.abc import Iterable
-from typing import Any, Union
+from typing import Any
 
 from .. import log_split_progress
-from .._docstrings import add_docstrings
-from ..types import DatetimeSplitBounds, DatetimeSplits
+from ..types import DatetimeSplitBounds, DatetimeSplits, LogSplitProgressKwargs, MetricsType
 
-LogProgressArg = Union[str, bool, dict[str, Any], logging.Logger, logging.LoggerAdapter]  # type: ignore[type-arg]
-
-add_docstrings(log_progress="Controls logging of fold progress. See :func:`~.log_split_progress` for details.")
+LogProgressArg = str | bool | logging.Logger | logging.LoggerAdapter[Any] | LogSplitProgressKwargs[MetricsType]
 
 
 def handle_log_progress_arg(
-    log_progress: LogProgressArg, *, splits: DatetimeSplits
+    log_progress: LogProgressArg[MetricsType], *, splits: DatetimeSplits
 ) -> Iterable[DatetimeSplitBounds] | None:
     """Wrapper function for integrations."""
     if log_progress is True:
