@@ -12,12 +12,14 @@ dependencies if you need to use the ``support`` module.
 """
 
 from .._backend import DatetimeIndexSplitter, expand_limits, process_available
-from .._frontend import fold_weight, to_string
+from .._frontend import default_metrics_formatter, fold_weight, format_expanded_limits, to_string
 
 __all__ = [
     "DatetimeIndexSplitter",
+    "default_metrics_formatter",
     "expand_limits",
-    "process_available",
     "fold_weight",
+    "format_expanded_limits",
+    "process_available",
     "to_string",
 ]
